==> sdd.ebfapi.server-0.4.6-sources.jar: ar/com/sdd/ebfapi/api/erp/ErpDocumentEbfApiEndpoint.java <==
package ar.com.sdd.ebfapi.api.erp;

import ar.com.sdd.commons.rest.log.ServerFileLogged;
import ar.com.sdd.ebfapi.client.model.erp.ErpDocumentAttach;
import ar.com.sdd.ebfapi.client.model.erp.ErpDocumentCommentSet;
import ar.com.sdd.ebfapi.client.model.erp.ErpDocumentSet;

import javax.inject.Inject;
import javax.ws.rs.*;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.SecurityContext;

@Path("/ebfapi/v1_1/erp-document")
public class ErpDocumentEbfApiEndpoint {

    @Inject private ErpDocumentEbfApiService erpDocumentEbfApiService;

    @POST
    @ServerFileLogged
    @Path("/aid/{aid}/owner/{ownerId}/erp-document-set")
    @Consumes({"application/json"})
    @Produces("application/json; charset=utf-8")
    public Response postErpDocumentSet(@HeaderParam("Authorization") String authorization, @PathParam("aid") String applicationId, @PathParam("ownerId") String ownerId, ErpDocumentSet erpDocumentSet, @Context SecurityContext securityContext) {
        return erpDocumentEbfApiService.postErpDocumentSet(authorization, applicationId, ownerId, erpDocumentSet, securityContext);
    }



    @POST
    @ServerFileLogged
    @Path("/aid/{aid}/owner/{ownerId}/erp-documentAttach")
    @Consumes({"application/json"})
    @Produces("application/json; charset=utf-8")
    public Response postErpDocumentAttach(@HeaderParam("Authorization") String authorization, @PathParam("aid") String applicationId, @PathParam("ownerId") String ownerId, ErpDocumentAttach erpDocumentAttach, @Context SecurityContext securityContext) {
        return erpDocumentEbfApiService.postErpDocumentAttach(authorization, applicationId, ownerId, erpDocumentAttach, securityContext);
    }

    @GET
    @ServerFileLogged
    @Path("/aid/{aid}/owner/{ownerId}/erp-documentAttach/orderNumber/{orderNumber}/attach-link")
    @Consumes({"application/json"})
    @Produces("application/json; charset=utf-8")
    public Response getErpDocumentAttach(@HeaderParam("Authorization") String authorization, @PathParam("aid") String applicationId, @PathParam("ownerId") String ownerId, @PathParam("orderNumber") String orderNumber, @Context SecurityContext securityContext) {
        return erpDocumentEbfApiService.getErpDocumentAttachLink(authorization, applicationId, ownerId, orderNumber, securityContext);
    }



    @POST
    @ServerFileLogged
    @Path("/aid/{aid}/owner/{ownerId}/erp-documentComment-set")
    @Consumes({"application/json"})
    @Produces("application/json; charset=utf-8")
    public Response postErpDocumentCommentSet(@HeaderParam("Authorization") String authorization, @PathParam("aid") String applicationId, @PathParam("ownerId") String ownerId, ErpDocumentCommentSet erpDocumentCommentSet, @Context SecurityContext securityContext) {
        return erpDocumentEbfApiService.postErpDocumentCommentSet(authorization, applicationId, ownerId, erpDocumentCommentSet, securityContext);
    }
}

==> sdd.ebfapi.server-0.4.11-sources.jar: ar/com/sdd/ebfapi/api/erp/ErpDocumentEbfApiEndpoint.java <==
package ar.com.sdd.ebfapi.api.erp;

import ar.com.sdd.commons.rest.log.ServerFileLogged;
import ar.com.sdd.ebfapi.client.model.erp.ErpDocumentAttach;
import ar.com.sdd.ebfapi.client.model.erp.ErpDocumentCommentSet;
import ar.com.sdd.ebfapi.client.model.erp.ErpDocumentSet;

import javax.inject.Inject;
import javax.ws.rs.*;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.SecurityContext;

@Path("/ebfapi/v1_1/erp-document")
public class ErpDocumentEbfApiEndpoint {

    @Inject
    private ErpDocumentEbfApiService erpDocumentEbfApiService;

    @POST
    @ServerFileLogged
    @Path("/aid/{aid}/owner/{ownerId}/erp-document-set")
    @Consumes({"application/json"})
    @Produces("application/json; charset=utf-8")
    public Response postErpDocumentSet(@HeaderParam("Authorization") String authorization, @PathParam("aid") String applicationId, @PathParam("ownerId") String ownerId, ErpDocumentSet erpDocumentSet, @Context SecurityContext securityContext) {
        return erpDocumentEbfApiService.postErpDocumentSet(authorization, applicationId, ownerId, erpDocumentSet, securityContext);
    }

    @POST
    @ServerFileLogged
    @Path("/aid/{aid}/owner/{ownerId}/erp-documentAttach")
    @Consumes({"application/json"})
    @Produces("application/json; charset=utf-8")
    public Response postErpDocumentAttach(@HeaderParam("Authorization") String authorization, @PathParam("aid") String applicationId, @PathParam("ownerId") String ownerId, ErpDocumentAttach erpDocumentAttach, @Context SecurityContext securityContext) {
        return erpDocumentEbfApiService.postErpDocumentAttach(authorization, applicationId, ownerId, erpDocumentAttach, securityContext);
    }

    @POST
    @ServerFileLogged
    @Path("/aid/{aid}/owner/{ownerId}/erp-documentComment-set")
    @Consumes({"application/json"})
    @Produces("application/json; charset=utf-8")
    public Response postErpDocumentCommentSet(@HeaderParam("Authorization") String authorization, @PathParam("aid") String applicationId, @PathParam("ownerId") String ownerId, ErpDocumentCommentSet erpDocumentCommentSet, @Context SecurityContext securityContext) {
        return erpDocumentEbfApiService.postErpDocumentCommentSet(authorization, applicationId, ownerId, erpDocumentCommentSet, securityContext);
    }
}
